@@ -5,7 +5,7 @@ use strict;
 use warnings 'all';
 no warnings 'uninitialized';
 
-our $VERSION = '1.01';
+our $VERSION = '1.011';
 our %GEN;
 
 my ($idx, $fl_set_ldr);
@@ -76,8 +76,8 @@ sub gen{
     }
 
     $GEN{$fn} = $s;
-    $h->{fl_no_ldr} || $h->{fl_set_ldr} || (
-	$h->{fl_set_ldr}++,
+    $fl_set_ldr || $h->{fl_no_ldr} || (
+	$fl_set_ldr++,
 	$idx = unshift(@INC, $ldr),
     );
 
@@ -111,7 +111,7 @@ Constant::Generator - this module bring flexible (I hope) constant generator to
 
 =head1 VERSION
 
-version 1.01
+version 1.011
 
 =head1 DESCRIPTION
 
@@ -126,7 +126,7 @@ Let me save Your time in constant generation :).
     # eval use constant {ERR_SUCCESS => 1, ERR_PERMS => 2} and put constant names to @EXPORT_OK
     Constant::Generator::gen('Sys::Errors', [qw/success perms/], {fl_exp_ok => 1, prfx => 'ERR_',});
 
-    # eval use constatnt {EV_SYNC => 1, EV_TIMEOUT => 2} and put EV_* constant name to @EXPORT
+    # eval use constant {EV_SYNC => 1, EV_TIMEOUT => 2} and put EV_* constant name to @EXPORT
     Constant::Generator::gen('Sys::Events', [qw/sync timeout/], {fl_exp => 1, prfx => 'EV_',});
 
     # generate source code and save pm-file in specified path
@@ -183,7 +183,7 @@ constants
 =item  fl_exp_ok
 
 (`flag EXPORT_OK') make constants exportable, but no autoexport (fill @EXPORT_OK, man Exporter);
-so use Sys::Event qw'ALERT' will export ALERT constants
+so use Sys::Event qw'ALERT' will export ALERT constant
 
 =item  prfx
 
@@ -228,7 +228,7 @@ generate constant values, ex:
 
 =item  fl_rev
 
-(`flag reverse declaration') same as abonve but reversed pair (values => keys) will be available at
+(`flag reverse declaration') same as above but reversed pair (values => keys) will be available at
 %{__PACKAGE__::STSNOC} hash
 
 =item  fl_no_load
